# Flatbuffers

FlatBuffers is a cross platform serialization library architected for maximum
memory efficiency. It allows you to directly access serialized data without
parsing/unpacking it first, while still having great forwards/backwards
compatibility. It was originally created at Google for game development and
other performance-critical applications.

## See our
* [Tutorial](https://google.github.io/flatbuffers/flatbuffers_guide_tutorial.html)
* [Landing Page](https://google.github.io/flatbuffers/)
* [Rust sample binary](https://github.com/google/flatbuffers/blob/master/samples/sample_binary.rs)
* [Schema**less** format, Flexbuffers](https://crates.io/crates/flexbuffers)
* [Github](https://github.com/google/flatbuffers)

